#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const commander_1 = __importDefault(require("commander"));
const colors_1 = __importDefault(require("colors"));
const lerna_json_1 = require("./lerna.json");
const actions_js_1 = require("./actions.js");
const gitCredential_js_1 = require("./gitCredential.js");
const gitAnnexRemote_js_1 = require("./gitAnnexRemote.js");
const createDataset_js_1 = require("./createDataset.js");
/**
 * display the help text in red on the console
 */
function makeRed(txt) {
    return colors_1.default.red(txt);
}
commander_1.default.version(lerna_json_1.version).description('OpenNeuro command line tools.');
commander_1.default.on('--help', () => {
    console.log('');
    console.log('See additional options for each command with "openneuro [command] --help". Example:');
    console.log('  $ openneuro upload --help');
});
commander_1.default
    .command('login')
    .alias('l')
    .description('Setup authentication with OpenNeuro')
    .action(actions_js_1.login);
commander_1.default
    .command('upload <dir>')
    .alias('u')
    .description('Upload or sync a dataset (if a accession number is provided)')
    .option('-d, --dataset [dsId]', 'Specify the dataset to update, use this to resume uploads or add new files')
    .option('-i, --ignoreWarnings', 'Ignore validation warnings when uploading')
    .option('-n, --ignoreNiftiHeaders', 'Disregard NIfTI header content during validation')
    .option('--ignoreSubjectConsistency', 'Skip checking that any given file for one subject is present for all other subjects')
    .option('-v, --verbose', 'Verbose output')
    .action(actions_js_1.upload);
commander_1.default
    .command('download <datasetId> <destination>')
    .alias('d')
    .description('Download a dataset draft or snapshot. If neither is specified, will prompt with available snapshots.')
    .option('--draft')
    .option('-s, --snapshot [snapshotVersion]')
    .action(actions_js_1.download);
commander_1.default
    .command('git-credential <operation>')
    .description('A git credentials helper for easier datalad or git-annex access to datasets.')
    .action(gitCredential_js_1.gitCredential);
commander_1.default
    .command('create-dataset')
    .alias('c')
    .description('Create a new empty dataset, useful for adding existing DataLad or git-annex datasets.')
    .action(() => {
    createDataset_js_1.create();
});
commander_1.default
    .command('*', 'default', { noHelp: true, isDefault: true })
    .action(() => {
    // eslint-disable-next-line no-console
    console.log('Unknown command!');
    commander_1.default.outputHelp(makeRed);
});
commander_1.default.parse(process.argv);
if (process.argv[1].endsWith('git-credential-openneuro')) {
    gitCredential_js_1.gitCredential();
}
else if (process.argv[1].endsWith('git-annex-remote-openneuro')) {
    gitAnnexRemote_js_1.gitAnnexRemote();
}
else if (!process.argv.slice(2).length) {
    commander_1.default.outputHelp(makeRed);
}
