"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getErrorReporting = exports.getUrl = exports.getUser = exports.getToken = exports.saveConfig = exports.readConfig = exports.getConfig = void 0;
const fs_1 = __importDefault(require("fs"));
const os_1 = __importDefault(require("os"));
const path_1 = __importDefault(require("path"));
const find_config_1 = __importDefault(require("find-config"));
const jwt_decode_1 = __importDefault(require("jwt-decode"));
/**
 * Get the nearest working configuration
 */
exports.getConfig = () => {
    return find_config_1.default('.openneuro');
};
exports.readConfig = () => {
    const config = exports.getConfig();
    if (config) {
        return fs_1.default.readFileSync(config, 'utf8');
    }
    else {
        return JSON.stringify({});
    }
};
/**
 * Save a config object to a default location
 *
 * `$HOME/.openneuro`
 *
 * @param {Object} config
 */
exports.saveConfig = config => {
    const home = os_1.default.homedir();
    const savePath = path_1.default.join(home, '.openneuro');
    fs_1.default.writeFileSync(savePath, JSON.stringify(config));
};
/**
 * Read the current configuration and return the configured token or throw an error
 */
exports.getToken = () => {
    const config = JSON.parse(exports.readConfig());
    if (config.hasOwnProperty('apikey')) {
        return config.apikey;
    }
    else {
        throw new Error('You must have an API key configured to continue, try `openneuro login` first');
    }
};
/**
 * Get the user object from the configured token
 * @returns {any}
 */
exports.getUser = () => {
    const token = exports.getToken();
    return jwt_decode_1.default(token);
};
exports.getUrl = () => {
    const config = JSON.parse(exports.readConfig());
    if (config.hasOwnProperty('url')) {
        return config.url;
    }
    else {
        throw new Error('You must have a URL configured to continue, try `openneuro login` first');
    }
};
exports.getErrorReporting = () => {
    const config = JSON.parse(exports.readConfig());
    if (config.hasOwnProperty('errorReporting') &&
        config.hasOwnProperty('url') &&
        config.errorReporting) {
        return config.url;
    }
    else {
        return false;
    }
};
