"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.create = exports.createDataset = void 0;
const client_1 = require("@apollo/client");
const inquirer_1 = __importDefault(require("inquirer"));
const config_js_1 = require("./config.js");
const configuredClient_js_1 = require("./configuredClient.js");
const apm_js_1 = require("./apm.js");
const CREATE_DATASET = client_1.gql `
  mutation createDataset($affirmedDefaced: Boolean, $affirmedConsent: Boolean) {
    createDataset(
      affirmedDefaced: $affirmedDefaced
      affirmedConsent: $affirmedConsent
    ) {
      id
      worker
    }
  }
`;
exports.createDataset = async ({ affirmedDefaced, affirmedConsent }) => {
    const apmTransaction = apm_js_1.apm.startTransaction('createDataset', 'custom');
    const url = config_js_1.getUrl();
    const client = configuredClient_js_1.configuredClient();
    try {
        const { data } = await client.mutate({
            mutation: CREATE_DATASET,
            variables: { affirmedDefaced, affirmedConsent },
        });
        const datasetId = data.createDataset.id;
        // Full worker value is something like "openneuro-worker-2"
        const worker = data.createDataset.worker.split('-').pop();
        console.log(`Dataset ${url}datasets/${datasetId} created.`);
        console.log(`Git remote: ${url}git/${worker}/${datasetId}`);
    }
    catch (err) {
        console.log('Dataset creation failed, you may need to rerun setup with "openneuro login" first');
    }
    apmTransaction.end();
};
exports.create = () => {
    inquirer_1.default
        .prompt({
        type: 'list',
        name: 'affirmed',
        message: 'Please affirm one of the following:',
        choices: [
            'All structural scans have been defaced, obscuring any tissue on or near the face that could potentially be used to reconstruct the facial structure.',
            'I have explicit participant consent and ethical authorization to publish structural scans without defacing.',
        ],
    })
        .then(({ affirmed: [affirmedDefaced, affirmedConsent] }) => exports.createDataset({
        affirmedDefaced: !!affirmedDefaced,
        affirmedConsent: !!affirmedConsent,
    }));
};
