"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createDataset = exports.getDatasetFiles = exports.getDataset = void 0;
const openneuro_client_1 = require("openneuro-client");
/**
 * Check for an existing dataset
 * @param {object} client
 * @param {string} dir
 * @param {string} datasetId
 */
exports.getDataset = (client, dir, datasetId) => {
    return client
        .query({
        query: openneuro_client_1.datasets.getDataset,
        variables: { id: datasetId },
    })
        .then(() => datasetId);
};
/**
 * Get an existing dataset's files
 * @param {object} client GraphQL client
 * @param {*} datasetId
 */
exports.getDatasetFiles = (client, datasetId) => {
    return client.query({
        query: openneuro_client_1.datasets.getDraftFiles,
        variables: { id: datasetId },
    });
};
/**
 * Create a dataset and return the new accession number
 * @param {object} client
 */
exports.createDataset = client => ({ affirmedDefaced, affirmedConsent, }) => {
    return client
        .mutate({
        mutation: openneuro_client_1.datasets.createDataset,
        variables: { affirmedDefaced, affirmedConsent },
    })
        .then(({ data }) => {
        const dsId = data.createDataset.id;
        // eslint-disable-next-line no-console
        console.log(`"${dsId}" created`);
        return dsId;
    });
};
