"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getFiles = exports.bytesToSize = void 0;
const fs_1 = require("fs");
const path_1 = __importDefault(require("path"));
exports.bytesToSize = bytes => {
    const sizes = ['Bytes', 'KB', 'MB', 'GB', 'TB'];
    if (bytes === 0)
        return 'n/a';
    const i = parseInt(String(Math.floor(Math.log(bytes) / Math.log(1024))), 10);
    if (i === 0)
        return `${bytes} ${sizes[i]}`;
    return `${(bytes / 1024 ** i).toFixed(1)} ${sizes[i]}`;
};
/**
 * Simplified generator walk of all files in a tree
 * @param {string} dir
 */
async function* getFiles(dir) {
    const dirents = await fs_1.promises.readdir(dir, { withFileTypes: true });
    for (const dirent of dirents) {
        const res = path_1.default.resolve(dir, dirent.name);
        if (dirent.isDirectory()) {
            yield* getFiles(res);
        }
        else {
            yield res;
        }
    }
}
exports.getFiles = getFiles;
