"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.gitCredential = exports.getRepoToken = void 0;
const readline_1 = __importDefault(require("readline"));
const configuredClient_js_1 = require("./configuredClient.js");
const client_1 = require("@apollo/client");
const prepareRepoAccess = client_1.gql `
  mutation prepareRepoAccess($datasetId: ID!) {
    prepareRepoAccess(datasetId: $datasetId) {
      token
      endpoint
    }
  }
`;
function getRepoToken(datasetId) {
    const client = configuredClient_js_1.configuredClient();
    return client
        .mutate({
        mutation: prepareRepoAccess,
        variables: {
            datasetId,
        },
    })
        .then(({ data }) => data.prepareRepoAccess.token);
}
exports.getRepoToken = getRepoToken;
/**
 * @typedef {Object} Credential
 * @property {string} [path]
 */
function gitCredential() {
    /** @type {Credential} */
    const credential = {};
    const stdin = readline_1.default.createInterface({
        input: process.stdin,
    });
    stdin.on('line', line => {
        const [key, value] = line.split('=', 2);
        credential[key] = value;
    });
    stdin.on('close', () => {
        if ('path' in credential) {
            const datasetId = credential.path.split('/').pop();
            getRepoToken(datasetId).then(token => {
                const output = {
                    username: 'openneuro-cli',
                    password: token,
                };
                for (const key in output) {
                    console.log(`${key}=${output[key]}`);
                }
            });
        }
        else {
            throw new Error('Invalid input from git, check the credential helper is configured correctly');
        }
    });
}
exports.gitCredential = gitCredential;
