/**
 * Create a Request object for this url and key
 * @param {object} state
 * @param {string} state.url Base URL
 * @param {string} state.token Basic auth token for repos
 * @param {string} key git-annex key
 * @param {object} options fetch options
 * @returns {Request} Configured fetch Request object
 */
export function keyRequest(state: {
    url: string;
    token: string;
}, key: string, options: object): Request;
/**
 * Call POST to upload a key to a remote
 * @param {object} state
 * @param {string} state.url Base URL
 * @param {string} state.token Basic auth token for repos
 * @param {string} key Git-annex key
 * @param {string} file File path
 */
export function storeKey(state: {
    url: string;
    token: string;
}, key: string, file: string): Promise<boolean>;
/**
 * Call GET to download a key from a remote
 * @param {object} state
 * @param {string} state.url Base URL
 * @param {string} state.token Basic auth token for repos
 * @param {string} key Git-annex key
 * @param {string} file File path
 */
export function retrieveKey(state: {
    url: string;
    token: string;
}, key: string, file: string): Promise<boolean>;
/**
 * Call HEAD to check if key exists on remote
 * @param {object} state
 * @param {string} state.url Base URL
 * @param {string} state.token Basic auth token for repos
 * @param {string} key
 * @returns {Promise<boolean>} True or false if key exists
 */
export function checkKey(state: {
    url: string;
    token: string;
}, key: string): Promise<boolean>;
/**
 * Call DELETE to remove a key from the remote
 * @param {object} state
 * @param {string} state.url Base URL
 * @param {string} state.token Basic auth token for repos
 * @param {string} key
 * @returns {Promise<boolean>} True or false if key exists
 */
export function removeKey(state: {
    url: string;
    token: string;
}, key: string): Promise<boolean>;
import { Request } from "fetch-h2";
//# sourceMappingURL=transferKey.d.ts.map